@@ -112,4 +112,4 @@ class HuobiService:
             return 0
 
         rst = await func(contract_code=contract_code)
-        return int(abs(math.log10(rst.data['price_tick'])))
+        return int(abs(math.log10(rst.data[0]['price_tick'])))
