@@ -225,6 +225,43 @@ class AsyncClient(BaseClient):
         """
         return await self._request_account_api(path="config")
 
+    async def set_leverage(self, instId, lever, mgnMode, posSide="net"):
+        """
+        设置杠杆倍数
+        一个产品可以有如下几种杠杆倍数的设置场景：
+        币币杠杆逐仓杠杆倍数（币对层面）；
+        币币杠杆单币种保证金模式下全仓杠杆倍数（币对层面）；
+        币币杠杆跨币种保证金模式下全仓杠杆倍数（币种层面）；
+        交割/永续逐仓/全仓杠杆倍数（合约/指数层面）
+
+        instId	String	可选	产品ID：币对、合约
+                            instId和ccy至少要传一个；如果两个都传，默认使用instId
+        ccy	String	可选	保证金币种
+                    仅适用于跨币种保证金模式的全仓 币币杠杆。
+        lever	String	是	杠杆倍数
+        mgnMode	String	是	保证金模式
+        isolated：逐仓 cross：全仓
+                        如果ccy有效传值，该参数值只能为cross。
+        posSide	String	可选	持仓方向
+                        long：双向持仓多头
+                        short：双向持仓空头
+                        net：单向持仓
+                        在双向持仓且保证金模式为逐仓条件下必填，且仅可选择 long或short，其他情况下非必填，默认net；仅适用于交割/永续
+        """
+        data = package_data(remove_key(locals()))
+        return await self._request_account_api("post", "set-leverage", data=data)
+
+    async def get_leverage(self, instId, mgnMode):
+        """
+        获取杠杆倍数
+        instId	String	是	产品ID
+                        支持多个instId查询，半角逗号分隔。instId个数不超过20个
+        mgnMode	String	是	保证金模式
+                        isolated：逐仓 cross：全仓
+        """
+        params = package_data(remove_key(locals()))
+        return await self._request_account_api(path="leverage-info", params=params)
+
     async def set_position_mode(self, posMode: PosMode):
         """
         设置持仓模式
@@ -350,7 +387,7 @@ class AsyncClient(BaseClient):
         uly	String	否	合约标的指数
         instId	String	否	产品ID，如 BTC-USD-SWAP
         """
-        assert instType in (InstType.SWAP, InstType.FUTURES, InstType.OPTION, InstType.MARGIN)
+        assert instType in (InstType.SWAP.value, InstType.FUTURES.value, InstType.OPTION.value, InstType.MARGIN.value)
         params = package_data(remove_key(locals()))
         return await self._request_public_api(path="mark-price", params=params)
 
@@ -520,6 +557,16 @@ class AsyncClient(BaseClient):
         params = package_data(remove_key(locals()))
         return await self._request_trade_api(path="orders-history", params=params)
 
+    async def orders_history_archive(self, instType: InstType, uly: str = None, instId=None, ordType: OrderType = None,
+                                     state: OrderState = None, category: OrderCategory = None, after=None, before=None,
+                                     limit=100):
+        """
+        获取最近3个月的已经完结状态的订单数据，已经撤销的未成交单 只保留2小时
+        参数含义同上
+        """
+        params = package_data(remove_key(locals()))
+        return await self._request_trade_api(path="orders-history-archive", params=params)
+
     async def fills(self, instType: InstType = None, uly=None, instId=None, ordId=None, after=None, before=None, limit=100):
         """
         获取近3个月订单成交明细信息
