@@ -1,3 +1,4 @@
+import math
 from common.okex.client import AsyncClient
 
 
@@ -18,3 +19,8 @@ class OkexService:
 
         if payload:
             await self.client.batch_cancel_orders(payload)
+
+    async def get_price_tick_size(self, instType, instId) -> int:
+        # 获取交易价格精度
+        rst = await self.client.instruments(instType=instType, instId=instId)
+        return int(abs(math.log10(float(rst.data[0]['tickSz']))))
