@@ -198,7 +198,12 @@ class ReconnectingWebSocket:
                 data = json.loads(uncompress_data)
             except:
                 data = uncompress_data
-        elif msg.type == aiohttp.WSMsgType.CLOSE:
+        elif msg.type in (
+                aiohttp.WSMsgType.CLOSE,
+                aiohttp.WSMsgType.CLOSING,
+                aiohttp.WSMsgType.CLOSED,
+                aiohttp.WSMsgType.ERROR
+        ):
             data = None
         else:
             raise OkexWebSocketError(f"invalid msg type: {msg.type}")
